@@ -17,8 +17,8 @@
 #' @keywords utility
 # @importFrom mgcv uniquecombs
 #' @importFrom stats integrate
-integratepdf <- function(ddfobj, select, width, int.range,
-                         standardize=TRUE, point=FALSE, left=0, doeachint=FALSE){
+integratepdf <- function(ddfobj, select, width, int.range, standardize=TRUE,
+                         point=FALSE, left=0, doeachint=FALSE){
   # Make sure there is consistency between integration ranges and data
   # It is ok to have a single observation with multiple ranges or a single range
   # with multiple observations but otherwise the numbers must agree if both >1
@@ -52,7 +52,7 @@ integratepdf <- function(ddfobj, select, width, int.range,
   # if there is only 1 integral to compute (no covariates/1 set of covariates
   # & only one set of integration ranges), that's easy
   if(nobs==1){
-    return(gstdint(int.range[1,], ddfobj=ddfobj, index=1, select=NULL,
+    return(gstdint(int.range[1, ], ddfobj=ddfobj, index=1, select=NULL,
                    width=width, standardize=standardize, point=point,
                    stdint=FALSE, left=left))
   }else{
@@ -66,16 +66,16 @@ integratepdf <- function(ddfobj, select, width, int.range,
     }
 
     ### find unique observations
-    # need unique model matrix-int.range combinations
-    # want them within those rows we selected to compute for
-    #   we know from above that int.range has either nrow(data) rows or
-    #   length(index) rows.
+    # need unique (model matrix)-(int.range) combinations
+    # want them within the rows we selected to compute for.
+    # Know from above that int.range has either nrow(data) rows or
+    #  length(index) rows.
     if(is.null(ddfobj$shape)){
       newdat <- cbind(ddfobj$scale$dm[index, , drop=FALSE], int.range)
     }else{
       if(ncol(ddfobj$shape$dm)>1){
         scale_dm <- ddfobj$shape$dm[index, , drop=FALSE]
-        scale_dm[,"(Intercept)"] <- NULL
+        scale_dm[, "(Intercept)"] <- NULL
       }else{
         scale_dm <- NULL
       }
@@ -89,11 +89,19 @@ integratepdf <- function(ddfobj, select, width, int.range,
     # generate the indices that we want to calculate integrals for
     ind <- match(uu.index, u.index)
 
+    if(length(width)==1){
+      width <- rep(width, nrow(int.range))
+    }
+    if(length(left)==1){
+      left <- rep(left, nrow(int.range))
+    }
+
+
     # calculate the integrals
-    ints <- gstdint(int.range[ind,,drop=FALSE], ddfobj=ddfobj,
-                    index=index[ind], select=NULL, width=width,
+    ints <- gstdint(int.range[ind, , drop=FALSE], ddfobj=ddfobj,
+                    index=index[ind], select=NULL, width=width[ind],
                     standardize=standardize, point=point,
-                    stdint=FALSE, left=left, doeachint=doeachint)
+                    stdint=FALSE, left=left[ind], doeachint=doeachint)
 
     ## now rebuild the integrals and populate the return vector
     integrals <- ints[attr(u.rows, "index")]
