@@ -26,15 +26,15 @@
 #' @param breaks user define breakpoints
 #' @param nc number of equal-width bins for histogram
 #' @param maintitle main title line for each plot
-#' @param showpoints logical variable; if TRUE plots predicted value for each
+#' @param showpoints logical variable; if \code{TRUE} plots predicted value for each
 #'   observation
-#' @param showlines logical variable; if TRUE a line representing the average
+#' @param showlines logical variable; if \code{TRUE} a line representing the average
 #'   detection probability is plotted
-#' @param ylim range of y axis; defaults to (0,1)
-#' @param angle shading angle for hatching
-#' @param density shading density for hatching
-#' @param col plotting colour
-#' @param jitter scaling option for plotting points.  Jitter is applied to
+#' @param ylim range of vertical axis; defaults to (0,1)
+#' @param angle shading angle for histogram bars.
+#' @param density shading density for histogram bars.
+#' @param col colour for histogram bars.
+#' @param jitter scaling option for plotting points. Jitter is applied to
 #'   points by multiplying the fitted value by a random draw from a normal
 #'   distribution with mean 1 and sd jitter.
 #' @param divisions number of divisions for averaging line values; default = 25
@@ -50,10 +50,10 @@
 #' @author Jeff Laake, Jon Bishop, David Borchers
 #' @keywords plot
 plot.trial.fi <- function(x, which=1:2, breaks=NULL, nc=NULL, maintitle="",
-                          showlines=TRUE, showpoints=TRUE, ylim=c(0,1),
-                          angle=-45,density=20,col="black",jitter=NULL,
-                          divisions=25,pages=0,xlab="Distance",
-                          ylab="Detection probability",subtitle=TRUE,...){
+                          showlines=TRUE, showpoints=TRUE, ylim=c(0, 1),
+                          angle=NULL, density=NULL, col="lightgrey",
+                          jitter=NULL, divisions=25, pages=0, xlab="Distance",
+                          ylab="Detection probability", subtitle=TRUE, ...){
 
   # Functions used: process.data, predict(predict.trial.fi), plot_uncond,
   #                 plot.cond
